@@ -89,11 +89,11 @@ def _parse_series(soup):
 def _parse_episode(soup):
     """Parse an episode listing. Return a dict"""
     e = dict(id=_g(soup, 'id', int),
-             combined_episode_number=_g(soup, 'combined_episodenumber', int),
+             combined_episode_number=_g(soup, 'combined_episodenumber'),
              combined_season=_g(soup, 'combined_season', int),
              dvd_chapter=_g(soup, 'dvd_chapter', int),
              dvd_disc_id=_g(soup, 'dvd_discid'),             
-             dvd_episode_number=_g(soup, 'dvd_episodenumber', int),
+             dvd_episode_number=_g(soup, 'dvd_episodenumber'),
              dvd_season=_g(soup, 'dvd_season', int),
              director=_g(soup, 'director'),
              name=_g(soup, 'episodename'),
@@ -179,16 +179,30 @@ def get_series(series_name_search):
         matches.append(_parse_series(series))
     return matches
 
+def get_series_details(series_id):
+    """Returns details on a single series, not including banners/episodes)"""
+    url = "%sapi/%s/series/%s/%s.xml" % (BASE_URL, API_KEY, series_id, _LANGUAGE)    
+    soup = BeautifulStoneSoup(urllib2.urlopen(url).read())
+    return _parse_series(soup.data)
+
+def get_episode(episode_id):
+    """Returns details on a single episode"""
+    url = "%sapi/%s/episodes/%s/%s.xml" % (BASE_URL, API_KEY, episode_id, _LANGUAGE)    
+    soup = BeautifulStoneSoup(urllib2.urlopen(url).read())
+    return _parse_episode(soup.data)
+    
+    
 
 def get_series_all(series_id, episodes=True, banners=True, actors=True):
     """Return all available data for a series."""
     url = "%sapi/%s/series/%s/all/%s.zip" % (BASE_URL, API_KEY, series_id, _LANGUAGE)
+
     filename, headers = urllib.urlretrieve(url)
     zf = ZipFile(file(filename))
     if episodes:
         soup = BeautifulStoneSoup(zf.read("%s.xml" % (_LANGUAGE, )))
         series = _parse_series(soup.find('series'))
-        series['episodes'] = [_parse_episode(e) for e in soup.findAll('Episode')]
+        series['episodes'] = [_parse_episode(e) for e in soup.findAll('episode')]
     
     if actors:
         soup = BeautifulStoneSoup(zf.read("actors.xml"))
@@ -254,6 +268,7 @@ def get_updates(since, for_series_ids=None):
     
     
 
+# Tests
 
 class TestSequenceFunctions(unittest.TestCase):
 
